@@ -4,13 +4,13 @@ package JSON::Schema::Draft201909::Vocabulary::Core;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema Draft 2019-09 Core vocabulary
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
 no if "$]" >= 5.033001, feature => 'multidimensional';
 no if "$]" >= 5.033006, feature => 'bareword_filehandles';
-use JSON::Schema::Draft201909::Utilities qw(is_type abort assert_keyword_type canonical_schema_uri E assert_uri_ref);
+use JSON::Schema::Draft201909::Utilities qw(is_type abort assert_keyword_type canonical_schema_uri E assert_uri_reference);
 use Moo;
 use strictures 2;
 use namespace::clean;
@@ -132,7 +132,7 @@ sub _eval_keyword_recursiveAnchor {
 sub _traverse_keyword_ref {
   my ($self, $schema, $state) = @_;
   return if not assert_keyword_type($state, $schema, 'string');
-  return if not assert_uri_ref($state, $schema);
+  return if not assert_uri_reference($state, $schema);
 }
 
 sub _eval_keyword_ref {
@@ -157,7 +157,7 @@ sub _eval_keyword_ref {
 sub _traverse_keyword_recursiveRef {
   my ($self, $schema, $state) = @_;
   return if not assert_keyword_type($state, $schema, 'string');
-  return if not assert_uri_ref($state, $schema);
+  return if not assert_uri_reference($state, $schema);
 }
 
 sub _eval_keyword_recursiveRef {
@@ -233,7 +233,7 @@ JSON::Schema::Draft201909::Vocabulary::Core - Implementation of the JSON Schema
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 DESCRIPTION
 
